#!/bin/bash

# BldHelper-release.sh
# This script is meant to be run on the build server and expects to find and update itself from adjacent repos.
# From PepDistroConfigs, these repos are ../PepProPixMaps & ../PepProTools and are vital to having a working build.

### ## # Set build working variables HERE # ## ###

PREFIX=AcorOS-budgie-5.3 	# Sets a unique final name of the ISO and checksum so <HouseKeeping> only removes 2 files .
SUFFIX=amd64		# Also used by <HouseKeeping>. And to distinguish between amd64 and x86 or devuan and ubuntu .
BUILD=release		# Sets which pepbld.sh to use and the location in /var/www/html/[release|rc|testing|nightly|unstable]

##################################################
### ## # Make NO Edits Below This Line !! # ## ###
##################################################

[ $TODAY ! = " " ] || TODAY=$(date -u +"%Y-%m-%d")	# If MasterBuilder.sh is used IT will set the date. If not used, we set it here.
FileName="${PREFIX}-${SUFFIX}"				# This will give a uniquely named and dated ISO and checksum for <HouseKeeping>.
LOCATION=/home/manuel/acoros-build/out/${BUILD}				# Tells <HouseKeeping> and the script which 2 files to remove and where to put them.
LogDir=/home/manuel/acoros-build/out/				# This folder contains a log for the last $[PREFIX]-$[SUFFIX] build.
WorkDir=/manuel/acoros-build/AcorOSbudgie86_64configs	# * If we change servers or locations T*H*I*S line is the O*N*L*Y line to change. *
_break=0 ; _wait=30	# Time (in seconds) to wait

# Move into the builder directory.
# Make sure the local repos are up to date.
cd  /home/manuel/acoros-build/
cd  ./AcorOSbudgie86_64configs && git pull --ff-only

# Run the build script - expect 50 minutes, allow 60.
 ./budgiebuild-64.sh 2>&1 | tee -a /tmp/${FileName}.out


# Timing matters, don't destroy the old one without a replacement.
# Check for the ISO to appear and wait for things to settle.
until [ -e build/*.iso ]
      do ((++_break))
	 [ $_break -gt $_wait ] && break || sleep 1
done

if [ ${_break} -lt ${_wait} ] ; then
### 10 June, 2022 - After 17 June, this comment and the following line can be removed
echo -e "\n\tISO appeared after $_break seconds.\n" | tee --append /tmp/${FileName}.out

mv build/*.iso build/${FileName}.iso

# Make the checksum file.
cd build
echo "# ${FileName} ${TODAY}" > ${FileName}-sha512.checksum
sha512sum ${FileName}.iso >> ${FileName}-sha512.checksum

### <HouseKeeping>
# Remove the previous files in ${LOCATION} .
rm -f ${LOCATION}/${FileName}*.iso
rm -f ${LOCATION}/${FileName}*-sha512.checksum

#mv $(FileName}*  ${LOCATION}/
mv ${FileName}.iso             ${LOCATION}/${FileName}.iso
mv ${FileName}-sha512.checksum ${LOCATION}/${FileName}-sha512.checksum

# touch -t ${_stamp} ${LOCATION} ${LOCATION}/${FileName}*
touch ${LOCATION}/${FileName}*

lb clean &

# Move the log file to the log directory.
[ ! -e ${LogDir} ] && mkdir -p ${LogDir}
mv /tmp/${FileName}.out ${LogDir}/${FileName}-${BUILD}.log
### </HouseKeeping>

else echo -e "\n\tAfter $_break seconds, ISO never appeared.\n" | tee --append /tmp/${FileName}.out
     mv /tmp/${FileName}.out ${LogDir}/${FileName}-${BUILD}.log
fi

